@@ -41,20 +41,18 @@
 #include <libgnomeui/gnome-ice.h>
 #include <libgnome/libgnome.h>
 
-#include "manager.h"
+#include "ice.h"
 #include "session.h"
-
-#define MAGIC_COOKIE_LEN 16
-#define ENVNAME "SESSION_MANAGER"
+#include "manager.h"
 
 /* Network ids.  */
 static char* ids;
 
-/* List of all auth entries.  */
+/* List of all the auth entries. */
 GSList *auth_entries;
 
 /* The "sockets" which we listen on */
-IceListenObj *sockets;
+static IceListenObj *sockets; 
 static gint *input_id;
 static gint num_sockets;
 
@@ -66,6 +64,10 @@ static IceAuthFileEntry* file_entry_new (const gchar* protocol,
 static GSList* read_authfile(gchar* filename);
 static void write_authfile(gchar* filename, GSList* entries);
 
+static GSList* watch_list = NULL;
+
+static gint original_umask;
+
 /* This is called when a client tries to connect. 
  * We still accept connections during a shutdown so we can handle warnings. */
 
@@ -123,19 +125,15 @@ accept_connection (gpointer client_data, gint source,
      connection.  */
   while (status2 == IceConnectPending)
     {
+      /* Freeze ice while doing the gtk iteration. We don't want to recurse
+         here */
+      ice_frozen();
       gtk_main_iteration ();
+      ice_thawed();
       status2 = IceConnectionStatus (connection);
     }
 }
 
-typedef struct {
-  IceConn        connection;
-  GDestroyNotify clean_up;
-  gpointer       data;
-} Watch;
-
-static GSList* watch_list = NULL;
-
 static void
 ice_watch (IceConn connection, IcePointer client_data, Bool opening,
 	   IcePointer *watch_data)
@@ -234,7 +232,7 @@ init_ice_connections (void)
 	int i;
 
 	for (i = 1; i < 256; i++){
-		sprintf (buffer, "-%d", i); 
+		g_snprintf (buffer, sizeof (buffer), "-%d", i); 
 		if (IceListenForWellKnownConnections (buffer, &num_sockets, &sockets, sizeof(error), error))
 			return TRUE;
 	}
@@ -247,6 +245,8 @@ init_ice_connections (void)
 void _IceTransNoListen (char *foo);
 #endif
 
+static int ice_depth = 0;
+
 void
 initialize_ice (void)
 {
@@ -343,6 +343,44 @@ initialize_ice (void)
 
   p = g_strconcat (ENVNAME "=", ids, NULL);
   putenv (p);
+  
+  ice_depth = 0;	/* We are live */
+}
+
+
+/*
+ *	Re-enable ice processing
+ */
+ 
+void ice_thawed(void)
+{
+	guint i;
+	
+	ice_depth--;
+	if(ice_depth)
+		return;
+	
+	/* Last disable cancelled so listen again */
+	for (i = 0; i < num_sockets; i++)
+	{
+		input_id[i] = gdk_input_add (IceGetListenConnectionNumber (sockets[i]),
+				   GDK_INPUT_READ, accept_connection,
+				   (gpointer) sockets[i]);
+	}
+}
+
+void ice_frozen(void)
+{
+	guint i;
+	
+	if(++ice_depth == 1)
+	{
+		/* First disable so turn off the events */
+		for (i = 0; i < num_sockets; i++)
+		{
+			gtk_input_remove (input_id[i]);      
+		}
+	}
 }
 
 void
@@ -379,6 +417,8 @@ clean_ice (void)
   g_free (input_id);
   free (ids);
   IceFreeListenObjs (num_sockets, sockets);
+  
+  ice_depth = ~0;	/* We are very frozen, like totally off */
 }
 
 /* Creates a new entry for inclusion in the ICE authority file and
@@ -410,7 +450,6 @@ file_entry_new (const gchar* protocol, const IceListenObj socket)
   return file_entry;
 }
 
-static gint original_umask;
 
 /* Reads a file containing ICE authority data */
 static GSList* 
