@@ -28,6 +28,7 @@
 typedef struct {
   GtkWidget *dialog;
   GnomeCanvasItem *label;
+  GnomeCanvasItem *label_shadow;
   GSList *icon_items;
   GSList *icon_pixbufs;
   GtkWidget *hbox;
@@ -65,7 +66,7 @@ static const SplashApp splash_map_table[] = {
 	{ N_("Session Manager Proxy"),        "gnome-smproxy",                  "gnome-session.png" },
 	{ N_("Window Manager"),               "gnome-wm",                       "gnome-ccwindowmanager.png" },
 	{ N_("Desktop"),                      "gmc",                            "gnome-ccdesktop.png" },
-	{ N_("Nautilus"),                     "nautilus",                       "gnome-launch-icon.png" },
+	{ N_("Nautilus"),                     "nautilus",                       "gnome-ccdesktop.png" },
 	{ NULL }
 };
 
@@ -215,6 +216,25 @@ check_icon_fit (void)
 	}
 }
 
+static void
+redo_shadow (SplashData *sd)
+{
+	double x, y, width, height;
+	gtk_object_get (GTK_OBJECT (sd->label),
+			"x", &x,
+			"y", &y,
+			"text_width", &width,
+			"text_height", &height,
+			NULL);
+	gnome_canvas_item_set (sd->label_shadow,
+			       "x1", x - (width/2.0) - 3.0,
+			       "y1", y - (height/2.0) - 1.0,
+			       "x2", x + (width/2.0) + 3.0,
+			       "y2", y + (height/2.0) + 1.0,
+			       NULL);
+}
+
+
 static gboolean
 icon_cb (gpointer data)
 {
@@ -280,6 +300,7 @@ icon_cb (gpointer data)
   }
 
   gnome_canvas_item_set (sd->label, "text", msg, NULL);
+  redo_shadow (sd);
 
   g_free (msg);
   g_free (text);
@@ -368,8 +389,31 @@ start_splash (gfloat max)
   {
     GdkPixbuf *pb;
     int height, width;
+    char *filename;
+    int maj, minor, pl;
 
-    pb = gdk_pixbuf_new_from_file (GNOME_ICONDIR "/splash/gnome-splash.png");
+    /* Find a splahsscreen by looking at "gnome-splash-major.minor.pl.png",
+       "gnome-splash-major.minor.png" and "gnome-splash.png" */
+    if (sscanf (VERSION, "%d.%d.%d", &maj, &minor, &pl) != 3) {
+	    pl = 0;
+	    if (sscanf (VERSION, "%d.%d", &maj, &minor) != 2) {
+		    maj = minor = pl = 0; /* sort of illegal version */
+	    }
+    }
+
+    filename = g_strdup_printf ("%s/splash/gnome-splash-%d.%d.%d.png",
+				GNOME_ICONDIR, maj, minor, pl);
+    pb = gdk_pixbuf_new_from_file (filename);
+    g_free (filename);
+    if (pb == NULL) {
+	    filename = g_strdup_printf ("%s/splash/gnome-splash-%d.%d.png",
+					GNOME_ICONDIR, maj, minor);
+	    pb = gdk_pixbuf_new_from_file (filename);
+	    g_free (filename);
+    }
+
+    if (pb == NULL)
+	    pb = gdk_pixbuf_new_from_file (GNOME_ICONDIR "/splash/gnome-splash.png");
 
     if (pb == NULL) {
 	    height = 220;
@@ -412,6 +456,15 @@ start_splash (gfloat max)
 				   NULL);
     }
 
+    sd->label_shadow = gnome_canvas_item_new (GNOME_CANVAS_GROUP (GNOME_CANVAS (sd->hbox)->root),
+					      GNOME_TYPE_CANVAS_RECT,
+					      /* fake */
+					      "x1", (gdouble)0.0,
+					      "y1", (gdouble)0.0,
+					      "x2", (gdouble)1.0,
+					      "y2", (gdouble)1.0,
+					      "fill_color_rgba", 0x00000080,
+					      NULL);
     sd->label = gnome_canvas_item_new (GNOME_CANVAS_GROUP (GNOME_CANVAS (sd->hbox)->root),
 				       GNOME_TYPE_CANVAS_TEXT,
 				       "text", _("Starting GNOME"),
@@ -421,6 +474,7 @@ start_splash (gfloat max)
 				       "anchor", GTK_ANCHOR_CENTER,
 				       "fill_color", "white",
 				       NULL);
+    redo_shadow (sd);
   }
 
   gtk_widget_show_all (sd->dialog);
