@@ -44,8 +44,8 @@ GList *newInfoTable(struct _toc_config *conf)
     struct _info_node *p;
     char last[BUFSIZ];
     int tmp_array_size = 256, tmp_array_elems = 0;
-    struct _info_node **tmp_array = g_new(struct _info_node *,
-                                          tmp_array_size);
+    struct _info_node **tmp_array = g_new0 (struct _info_node *,
+					    tmp_array_size);
 
     while (conf->path) {
 	if (conf->type != TOC_INFO_TYPE) {
@@ -140,13 +140,16 @@ static gchar *makeBaseName(gchar *name)
     gchar buf[BUFSIZ];
     gchar *end, *s, *ss;
 
-    strncpy(buf, name, sizeof(buf));
+    g_snprintf (buf, sizeof(buf), "%s", name);
     end = buf + strlen(buf);
 
     /* Strip off any trailing `.gz' */
     if ((strlen(buf) > 3) && !strcmp(end - 3, ".gz")) {
 	end -= 3;
 	*end = '\0';
+    }else if((strlen(buf) > 4) && !strcmp(end - 4, ".bz2")) {
+	end -= 4;
+	*end = '\0';
     }
 
     /* Strip and trailing `-nnnn' where `n' are numbers */
@@ -206,7 +209,7 @@ gint expandInfoTable(GList *table, gchar *name)
     gchar *rootFile;
 
     rootFile = ((struct _big_table_entry *)table->data)->filename;
-    if (loadFileToBuf(rootFile, &data, NULL)) {
+    if (loadFileToBuf(rootFile, &data, NULL) || !data) {
 	return -1;
     }
 
@@ -321,7 +324,7 @@ static gchar *findInfoFile(gchar *rootFile, gchar *name)
     gchar buf[BUFSIZ];
     gchar *s;
 
-    strncpy(buf, rootFile, sizeof(buf));
+    g_snprintf (buf, sizeof(buf), "%s", rootFile);
     s = strrchr(buf, '/');
     s++;
     *s = '\0';
@@ -336,6 +339,11 @@ static gchar *findInfoFile(gchar *rootFile, gchar *name)
     if (!access(buf, R_OK)) {
 	return g_strdup(buf);
     }
+    *strstr(buf,".gz")=0;
+    strcat(buf, ".bz2");
+    if (!access(buf, R_OK)) {
+	return g_strdup(buf);
+    }
 
     /* XXX this is goofy */
     return g_strdup("missing");
