@@ -25,15 +25,16 @@ struct _big_table_entry {
 
 typedef struct _toc *Toc;
 
-typedef void (*TocCB) (gchar *ref);
+Toc newToc(gchar *manPath, gchar *infoPath, gchar *ghelpPath);
 
-Toc newToc(gchar *manPath, gchar *infoPath, gchar *ghelpPath,
-	   TocCB callback);
-void showToc(Toc toc);
-void hideToc(Toc toc);
+GString *genManTocHTML(Toc res);
+GString *genInfoTocHTML(Toc res);
+GString *genGhelpTocHTML(Toc res);
 
 gchar *tocLookupInfo(Toc toc, gchar *name, gchar *anchor);
 gchar *tocLookupMan(Toc toc, gchar *name, gchar ext);
 gchar *tocLookupGhelp(Toc toc, gchar *name);
 
+GString *findMatchesBySubstr(Toc toc, const gchar *substr);
+
 #endif
