@@ -25,6 +25,7 @@ typedef GNOME_Panel_BackType PanelBackType;
 #define PANEL_BACK_NONE GNOME_Panel_BACK_NONE
 #define PANEL_BACK_COLOR GNOME_Panel_BACK_COLOR
 #define PANEL_BACK_PIXMAP GNOME_Panel_BACK_PIXMAP
+#define PANEL_BACK_TRANSLUCENT GNOME_Panel_BACK_TRANSLUCENT
 
 
 
@@ -47,4 +48,11 @@ typedef enum {
 	FOOBAR_PANEL
 } PanelType;
 
+typedef enum {
+	BORDER_TOP,
+	BORDER_RIGHT,
+	BORDER_BOTTOM,
+	BORDER_LEFT
+} BorderEdge;
+
 #endif
