@@ -15,6 +15,7 @@ struct _GlobalConfig {
 	gboolean tooltips_enabled;
 	/*gboolean show_small_icons;*/
 	gboolean show_dot_buttons;
+	gboolean show_menu_titles;
 	gboolean hungry_menus;
 	gboolean off_panel_popups;
 	PanelMovementType movement_type;
@@ -42,6 +43,12 @@ struct _GlobalConfig {
 	char *run_key;
 	  guint run_keysym;   /* these are not really properties but */
 	  guint run_state;    /* from the above */
+	char *screenshot_key;
+	  guint screenshot_keysym;   /* these are not really properties but */
+	  guint screenshot_state;    /* from the above */
+	char *window_screenshot_key;
+	  guint window_screenshot_keysym; /* these are not really properties */
+	  guint window_screenshot_state;  /* but from the above */
 	int menu_flags;
 	gboolean use_large_icons;
 	gboolean merge_menus;
